# coding=utf-8

import mysql.simplesql as sql

tables = ['tprices']


def insertTprices(tprice):
    # если не заполнено поле effectivedate, по просьбе клиента устанавливаем по-умолчанию 1970-01-02 00:00:00(2 янв, чтобы избежать проблем с часовым поясом)
    # на всякий случай удаляем доп.цены с таким же tindex и bcode за более раннюю дату (если у клиента были прогружены доп.цены с датой 0000-00-00 00:00:00)
    # http://redmine.artix.su/issues/48289
    effectivedate = getEffectiveDate(tprice)
    if effectivedate == '1970-01-02 00:00:00':
        yield sql.DeleteBeforeDate(table='tprices', whereFields=['tindex', 'bcode'],
                whereValues=[tprice.get('pricecode', None), tprice.get('barcode', tprice.get('inventcode', None))],
                dateField='effectivedate', dateValue='1970-01-02 00:00:01')
    yield sql.Insert(table='tprices', values={
        'tindex': tprice.get('pricecode', None),
        'bcode': tprice.get('barcode', tprice.get('inventcode', None)),
        'price': tprice.get('price', 0.0),
        'name': tprice.get('name', ''),
        'documentid': tprice.get('documentid', ''),
        'effectivedate': effectivedate,
        'packingprice': tprice.get('packingprice', None),
    })


def deleteTprices(tprice):
    yield sql.Delete(table='tprices', whereFields=['tindex', 'bcode', 'effectivedate'],
            whereValues=[tprice.get('pricecode', None), tprice.get('barcode', tprice.get('inventcode', None)),
                    getEffectiveDate(tprice)])


def clearTprices():
    yield sql.DeleteAll(table='tprices')


def deleteOutdatedTprices(barcode, pricecode, effectivedate):
    yield sql.DeleteBeforeDate(table='tprices', whereFields=['tindex', 'bcode'],
            whereValues=[pricecode, barcode], dateField='effectivedate', dateValue=effectivedate)


def deleteFutureTprices(barcode, pricecode, effectivedate):
    yield sql.DeleteAfterDate(table='tprices', whereFields=['tindex', 'bcode'],
            whereValues=[pricecode, barcode], dateField='effectivedate', dateValue=effectivedate)


def getEffectiveDate(tprice):
    effectivedate = tprice.get('effectivedate', None)
    if effectivedate is None or '0000-00-00' in effectivedate:
        effectivedate = "1970-01-02 00:00:00"
    return effectivedate
